<?php
// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Handles the display and processing of the category login shortcode.
 *
 * This is used to allow customers to login to their own product category using their category password.
 *
 * @package   WooCommerce_Protected_Categories
 * @author    Barn2 Media <info@barn2.co.uk>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */
class WC_PPC_Login_Shortcode {

	const SHORTCODE = 'category_login';

	public static function register_shortcode() {
		add_shortcode( self::SHORTCODE, array( __CLASS__, 'do_shortcode' ) );
	}

	/**
	 * Handles our client login shortcode.
	 *
	 * @param array $atts The attributes passed in to the shortcode
	 * @param string $content The content passed to the shortcode (not used)
	 * @return string The shortcode output
	 */
	public static function do_shortcode( $atts, $content = '' ) {
		$atts = shortcode_atts( array(
			'message'		 => false,
			'button_text'	 => false,
			'label'			 => false,
			'heading'		 => false,
			'show_heading'	 => true
			), $atts, self::SHORTCODE );

		// If these args are set to false, unset them so we use defaults from the plugin settings.
		foreach ( array( 'heading', 'message', 'button_text', 'label' ) as $att ) {
			if ( false === $atts[$att] ) {
				unset( $atts[$att] );
			}
		}

		$atts['show_heading'] = ( true === $atts['show_heading'] || 'true' === $atts['show_heading'] );

		return $content . WC_PPC_Password_Form::get_password_form( $atts );
	}

}
// class WC_PPC_Login_Shortcode
